
dialogId("ves-v-veci", "font_big", "There are most interesting things in this city!")
dialogStr("Er zijn een hoop interessante dingen in deze stad!")


dialogId("ves-m-krab", "font_small", "The poor crab!")
dialogStr("Arme krab!")


dialogId("ves-v-vyp", "font_big", "We should turn it off!")
dialogStr("Laten we dat ding uit zetten!")


dialogId("ves-m-uz", "font_small", "Oh, noo...")
dialogStr("O, neeee...")


dialogId("ves-v-pokoj", "font_big", "And it’s over.")
dialogStr("Eindelijk stilte.")


dialogId("ves-m-dik", "font_small", "Thank you player. We couldn’t bear it any longer.")
dialogStr("Bedankt, speler. We hadden het niet veel langer uit gehouden.")


dialogId("ves-v-stejne", "font_big", "But we have to push it down anyway.")
dialogStr("Maar we moeten het toch naar beneden duwen.")


dialogId("ves-hs-hrajeme", "font_statue", "Now listen to the bit of music!")
dialogStr("Luister nu maar naar wat muziek!")

